==> apeman-demo-bud-1.0.1.tgz: package/README.md <==
apeman-demo-bud
==========

<!-- Badge Start -->
<a name="badges"></a>

[![Build Status][bd_travis_shield_url]][bd_travis_url]
[![Code Climate][bd_codeclimate_shield_url]][bd_codeclimate_url]
[![Code Coverage][bd_codeclimate_coverage_shield_url]][bd_codeclimate_url]
[![npm Version][bd_npm_shield_url]][bd_npm_url]

[bd_repo_url]: https://github.com/apeman-demo-labo/apeman-demo-bud
[bd_travis_url]: http://travis-ci.org/apeman-demo-labo/apeman-demo-bud
[bd_travis_shield_url]: http://img.shields.io/travis/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_license_url]: https://github.com/apeman-demo-labo/apeman-demo-bud/blob/master/LICENSE
[bd_codeclimate_url]: http://codeclimate.com/github/apeman-demo-labo/apeman-demo-bud
[bd_codeclimate_shield_url]: http://img.shields.io/codeclimate/github/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_codeclimate_coverage_shield_url]: http://img.shields.io/codeclimate/coverage/github/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_gemnasium_url]: https://gemnasium.com/apeman-demo-labo/apeman-demo-bud
[bd_gemnasium_shield_url]: https://gemnasium.com/apeman-demo-labo/apeman-demo-bud.svg
[bd_npm_url]: http://www.npmjs.org/package/apeman-demo-bud
[bd_npm_shield_url]: http://img.shields.io/npm/v/apeman-demo-bud.svg?style=flat
[bd_bower_badge_url]: https://img.shields.io/bower/v/apeman-demo-bud.svg?style=flat

<!-- Badge End -->


<!-- Description Start -->
<a name="description"></a>

Demo of bud project.

<!-- Description End -->


<!-- Overview Start -->
<a name="overview"></a>


<!-- Overview End -->


<!-- Sections Start -->
<a name="sections"></a>

<!-- Section from "doc/readme/01.Installation.md.hbs" Start -->

<a name="section-doc-readme-01-installation-md"></a>
Installation
-----

```bash
$ npm install apeman-demo-bud --save
```

<!-- Section from "doc/readme/01.Installation.md.hbs" End -->

<!-- Section from "doc/readme/02.Usage.md.hbs" Start -->

<a name="section-doc-readme-02-usage-md"></a>
Usage
---------

```javascript
/**
 * A bud file to render with coz.
 */
"use strict";

var apemanDemoBud = require('apeman-demo-bud');

module.exports = apemanDemoBud({

});

if (!module.parent) {
    require('coz').render(__filename);
}
```

<!-- Section from "doc/readme/02.Usage.md.hbs" End -->


<!-- Sections Start -->


<!-- LICENSE Start -->
<a name="license"></a>

License
-------
This software is released under the [MIT License](https://github.com/apeman-demo-labo/apeman-demo-bud/blob/master/LICENSE).

<!-- LICENSE End -->


<!-- Links Start -->
<a name="links"></a>

Links
------

+ [apeman](https://github.com/apeman-labo/apeman)
+ [coz](https://github.com/coz-repo/coz)

<!-- Links End -->

==> apeman-demo-bud-1.0.2.tgz: package/README.md <==
apeman-demo-bud
==========

<!-- Badge Start -->
<a name="badges"></a>

[![Build Status][bd_travis_shield_url]][bd_travis_url]
[![Code Climate][bd_codeclimate_shield_url]][bd_codeclimate_url]
[![Code Coverage][bd_codeclimate_coverage_shield_url]][bd_codeclimate_url]
[![npm Version][bd_npm_shield_url]][bd_npm_url]

[bd_repo_url]: https://github.com/apeman-demo-labo/apeman-demo-bud
[bd_travis_url]: http://travis-ci.org/apeman-demo-labo/apeman-demo-bud
[bd_travis_shield_url]: http://img.shields.io/travis/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_license_url]: https://github.com/apeman-demo-labo/apeman-demo-bud/blob/master/LICENSE
[bd_codeclimate_url]: http://codeclimate.com/github/apeman-demo-labo/apeman-demo-bud
[bd_codeclimate_shield_url]: http://img.shields.io/codeclimate/github/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_codeclimate_coverage_shield_url]: http://img.shields.io/codeclimate/coverage/github/apeman-demo-labo/apeman-demo-bud.svg?style=flat
[bd_gemnasium_url]: https://gemnasium.com/apeman-demo-labo/apeman-demo-bud
[bd_gemnasium_shield_url]: https://gemnasium.com/apeman-demo-labo/apeman-demo-bud.svg
[bd_npm_url]: http://www.npmjs.org/package/apeman-demo-bud
[bd_npm_shield_url]: http://img.shields.io/npm/v/apeman-demo-bud.svg?style=flat
[bd_bower_badge_url]: https://img.shields.io/bower/v/apeman-demo-bud.svg?style=flat

<!-- Badge End -->


<!-- Description Start -->
<a name="description"></a>

Demo of bud project.

<!-- Description End -->


<!-- Overview Start -->
<a name="overview"></a>


<!-- Overview End -->


<!-- Sections Start -->
<a name="sections"></a>

<!-- Section from "doc/readme/01.Installation.md.hbs" Start -->

<a name="section-doc-readme-01-installation-md"></a>
Installation
-----

```bash
$ npm install apeman-demo-bud --save-dev
```

<!-- Section from "doc/readme/01.Installation.md.hbs" End -->

<!-- Section from "doc/readme/02.Usage.md.hbs" Start -->

<a name="section-doc-readme-02-usage-md"></a>
Usage
---------

```javascript
/**
 * A bud file to render with coz.
 */
"use strict";

var apemanDemoBud = require('apeman-demo-bud');

module.exports = apemanDemoBud({

});

if (!module.parent) {
    require('coz').render(__filename);
}
```

<!-- Section from "doc/readme/02.Usage.md.hbs" End -->


<!-- Sections Start -->


<!-- LICENSE Start -->
<a name="license"></a>

License
-------
This software is released under the [MIT License](https://github.com/apeman-demo-labo/apeman-demo-bud/blob/master/LICENSE).

<!-- LICENSE End -->


<!-- Links Start -->
<a name="links"></a>

Links
------

+ [apeman](https://github.com/apeman-labo/apeman)
+ [coz](https://github.com/coz-repo/coz)

<!-- Links End -->
